@@ -1,20 +1,16 @@
 <?php
-/* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
  * Application OctetStream Hex Transformations plugin for phpMyAdmin
- *
- * @package    PhpMyAdmin-Transformations
- * @subpackage Hex
  */
+
+declare(strict_types=1);
+
 namespace PhpMyAdmin\Plugins\Transformations\Output;
 
 use PhpMyAdmin\Plugins\Transformations\Abs\HexTransformationsPlugin;
 
 /**
  * Handles the hex transformation for application octetstream
- *
- * @package    PhpMyAdmin-Transformations
- * @subpackage Hex
  */
 // @codingStandardsIgnoreLine
 class Application_Octetstream_Hex extends HexTransformationsPlugin
@@ -26,7 +22,7 @@ class Application_Octetstream_Hex extends HexTransformationsPlugin
      */
     public static function getMIMEType()
     {
-        return "Application";
+        return 'Application';
     }
 
     /**
@@ -36,6 +32,6 @@ class Application_Octetstream_Hex extends HexTransformationsPlugin
      */
     public static function getMIMESubtype()
     {
-        return "OctetStream";
+        return 'OctetStream';
     }
 }
